@@ -23,7 +23,7 @@ LISTFILES=$(cat list-of-packages | egrep -v "^#" | egrep '(FD|FG|FO)' | cut -d"
 
 for i in $(echo $LISTFILES)
 do
-    echo $i; apt-get install --no-install-recommends -s $i | grep $1 && \
+    echo $i; apt-get install --no-install-recommends -s $i | grep '^Inst' | grep $1 && \
     { echo -e "\nBreaking...\n\nI found a package depending of $1: $i.\nPlease, fix list-of-files and run find-deps.sh again."; break; }
 done
 
